==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/GetSqlServerAvailabilityGroupDetailViewPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityGroupName Name of SQL Availability Group
 * @property resourceGroupName The name of the Azure resource group
 * @property sqlServerInstanceName Name of SQL Server Instance
 */
public data class GetSqlServerAvailabilityGroupDetailViewPlainArgs(
    public val availabilityGroupName: String,
    public val resourceGroupName: String,
    public val sqlServerInstanceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs =
        com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs.builder()
            .availabilityGroupName(availabilityGroupName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sqlServerInstanceName(sqlServerInstanceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlServerAvailabilityGroupDetailViewPlainArgs].
 */
@PulumiTagMarker
public class GetSqlServerAvailabilityGroupDetailViewPlainArgsBuilder internal constructor() {
    private var availabilityGroupName: String? = null

    private var resourceGroupName: String? = null

    private var sqlServerInstanceName: String? = null

    /**
     * @param value Name of SQL Availability Group
     */
    @JvmName("hqfttxwuacfnsolw")
    public suspend fun availabilityGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.availabilityGroupName = mapped
    }

    /**
     * @param value The name of the Azure resource group
     */
    @JvmName("jwiqhtygpqsrgdjb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of SQL Server Instance
     */
    @JvmName("tdjbdpoidrrnwacf")
    public suspend fun sqlServerInstanceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sqlServerInstanceName = mapped
    }

    internal fun build(): GetSqlServerAvailabilityGroupDetailViewPlainArgs =
        GetSqlServerAvailabilityGroupDetailViewPlainArgs(
            availabilityGroupName = availabilityGroupName ?: throw
                PulumiNullFieldException("availabilityGroupName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            sqlServerInstanceName = sqlServerInstanceName ?: throw
                PulumiNullFieldException("sqlServerInstanceName"),
        )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/GetSqlServerAvailabilityGroupDetailViewPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityGroupName Name of SQL Availability Group
 * @property resourceGroupName The name of the Azure resource group
 * @property sqlServerInstanceName Name of SQL Server Instance
 */
public data class GetSqlServerAvailabilityGroupDetailViewPlainArgs(
    public val availabilityGroupName: String,
    public val resourceGroupName: String,
    public val sqlServerInstanceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs =
        com.pulumi.azurenative.azurearcdata.inputs.GetSqlServerAvailabilityGroupDetailViewPlainArgs.builder()
            .availabilityGroupName(availabilityGroupName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sqlServerInstanceName(sqlServerInstanceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlServerAvailabilityGroupDetailViewPlainArgs].
 */
@PulumiTagMarker
public class GetSqlServerAvailabilityGroupDetailViewPlainArgsBuilder internal constructor() {
    private var availabilityGroupName: String? = null

    private var resourceGroupName: String? = null

    private var sqlServerInstanceName: String? = null

    /**
     * @param value Name of SQL Availability Group
     */
    @JvmName("ewkxsxpwmlrnqidg")
    public suspend fun availabilityGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.availabilityGroupName = mapped
    }

    /**
     * @param value The name of the Azure resource group
     */
    @JvmName("gmgipyqkbqvjogkp")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of SQL Server Instance
     */
    @JvmName("qlrvmutoeulwkcss")
    public suspend fun sqlServerInstanceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sqlServerInstanceName = mapped
    }

    internal fun build(): GetSqlServerAvailabilityGroupDetailViewPlainArgs =
        GetSqlServerAvailabilityGroupDetailViewPlainArgs(
            availabilityGroupName = availabilityGroupName ?: throw
                PulumiNullFieldException("availabilityGroupName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            sqlServerInstanceName = sqlServerInstanceName ?: throw
                PulumiNullFieldException("sqlServerInstanceName"),
        )
}
